---
title: Introduction
author: Lyz
---

This is my personal digital garden where I share everything
I know about this world in form of an online [MkDocs](https://www.mkdocs.org/)
book hosted on [GitHub](https://github.com/lyz-code/blue-book).

If this is your first visit, welcome!, you may be overwhelmed by the amount of
content and don't know where to start reading. A good entrypoint is meta,
where I describe this wiki, its structure and goals in more detail.

# Visiting the garden

You can search the contents of this wiki with the top search field or you can
explore the tree view to the left.

Start with the first article that grabs your attention and be ready to
incrementally read the rest.

Or you can use it as a reference, cloning the [git
repository](https://github.com/lyz-code/blue-book) and using grep like tools.

# Make your own digital garden

Don't be afraid to create one of your own and share what you know with the
world. If you don't want to build your own, I invite you to use a fork of
mine and make [contributions](#contributing). I would love to see the blue-book
maintained by multiple people.

You can view other similar gardens to get inspiration.

# Contributing

If you find a mistake or want to add new content, please make the changes. You
can use the edit button on the top right of any article to add them in a pull
request, if you don't know what that means, you cal always open an
[issue](https://github.com/lyz-code/blue-book/issues/new) or send me an
email.md).

# Thank you

If you liked my book and want to show your support, please see if you know how
can I fulfill any item of my wish list or contribute to my other projects.

[![CC0](https://img.shields.io/badge/license-CC0-0a0a0a.svg?style=flat&colorA=0a0a0a)](https://creativecommons.org/publicdomain/zero/1.0/)
